@@ -160,6 +160,8 @@ class NeptuneExperimentTracker(ExperimentTracker):
 
     def stop(self):
         self.tracker.stop()
+        if hasattr(self, "project"):
+            self.project.stop()
 
 
 os.environ["WANDB_START_METHOD"] = "thread"
